/* global page styles */
body {
  background-color: #efefef;
  color: #3E4545;
}

h1, h2, h3 {
  color: #254649;
}

h1 {
  font-size: 27px;
}

h3 {
  font-size: 19px;
}

h4 {
  color: #3C7461;
  font-size: 15px;
}

.da-page-header {
  margin-top: 0;
}

.tab-content>.tab-pane {
  background-color: #fff;
  border-radius: 10px;
  padding: 35px;
}

#daquestion {
  margin-top: 42px;
}

/* Navbar styles */
.navbar, .navbar.bg-dark {
    background-color: #254649 !important;
}

.danavbar-title {
  font-family: "'IBM Plex Serif', serif"
}

/* buttons */
.btn {
  border-radius: 28px;
  padding: 12px 24px;
}
.btn-primary, .btn-primary:hover, .btn-primary:focus, .btn-primary:active {
  background-color: #3c7461;
  border-color: #3c7461;
}
.btn-secondary, .btn-secondary:hover, .btn-secondary:focus, .btn-secondary:active {
  background-color: #fff;
  border-color: #CED4DA;
  color: #3E4545;
}

.button-group {
  text-align: center;
}

.bottom {
  position: absolute;
  bottom: 10px;
}

.da-review-action-button.btn-secondary {
  background-color: #D6D7F0;
  color: #3C7461;
  border-radius: 10px;
  padding: 10px 13px;
}

/* questions */
.progress-bar {
  background-color: #3C7461;
}

.btn-light {
  background-color: #EFEFEF;
}

/* tooltip */
a:not([href]):not([class]), a:not([href]):not([class]):hover {
  color: #3C7461;
}
div.dachoicehelp a {
  padding: 0;
  font-size: 18px;
}
div.dachoicehelp {
  vertical-align: center;
}

/* links */
a, a:visited, a:hover, a:focus, a:active {
  color: #3C7461;
}

a.btn-danger {
  color: #fff; 
}

a.btn-success:visited {
  color: #fff; 
}

/* pills progression */
.nav-pills .nav-link.active, .nav-pills .show>.nav-link {
  background-color: #3C7461;
}

.nav-pills .nav-link {
  color: #3C7461;
}

/* layout */
.flex {
  display: flex;
  column-gap: 20px;
}

.flex.center {
  align-items: center;
}

.grid-item {
  flex: 1;
  text-align: center;
  border: 1px solid #CED4DA;
  border-radius: 10px;
  padding: 32px 12px;
}

/* header banners */
.banner-image {
  text-align: center;
  border-radius: 8px;
}

#guardianshipOverviewHeader {
  background-color: #E0900E;
}

#guidedQuestionsHeader {
  background-color: #D6D7F0; 
}

#temporaryCareHeader {
  background-color: #d1988b;
}

#adoptionHeader {
  background-color: #ecbc6e;
}

/* review */
.da-review.bg-light {
  background-color: transparent !important;
}

.da-review .table>tbody {
  border-top: none;
  background-color: transparent
}

.da-review .table>tbody>tr>td{
  background-color: transparent;
  --bs-table-accent-bg: transparent;
}

/* results */
.result-wrapper {
  border: 2px solid #654F25;
  border-top: 5px solid #654F25;
  border-radius: 5px;
}

.result-wrapper h4 {
  color: #000;
  background-color: #e1dcd3;
  padding: 15px 30px;
}

.result-wrapper .result-body {
  padding: 20px 30px;
  font-size: 15px;
  color: #3e4545
}

.result-wrapper#temporaryCareResult {
  border: 2px solid #BE6C5A;
  border-top: 5px solid #BE6C5A;
}

.result-wrapper#temporaryCareResult h4 {
  background-color: #ebd2cd;
}

.result-wrapper#adoptionResult {
  border: 2px solid #E0900E;
  border-top: 5px solid #E0900E;
}

.result-wrapper#adoptionResult h4 {
  background-color: #f5ddb6;
}

/* DWH - Helper text boxes in guided document section */
.helper-wrapper {
  border: 2px solid #654F25;
  border-top: 5px solid #654F25;
  border-radius: 5px;
}

.helper-wrapper .helper-body {
  padding: 20px 30px;
  font-size: 15px;
  color: #3e4545
}

.helper-wrapper#temporaryCareHelper {
  border: 2px solid #BE6C5A;
  border-top: 5px solid #BE6C5A;
}

.helper-wrapper#adoptionHelper {
  border: 2px solid #E0900E;
  border-top: 5px solid #E0900E;
}

/* carry over from progressive disclosure */

a span.pdcaretopen {
  display: inline;
}

a span.pdcaretclosed {
  display: none;
}

a.collapsed .pdcaretopen {
  display: none;
}

a.collapsed .pdcaretclosed {
  display: inline;
}

.collapse {
  margin-bottom: 1em;
}